#!/usr/bin/perl
#
# mailaddrcrypt-cli: encrypt localpart
# author, (c): Philippe Kueck <projects at unixadm dot org>
#

use strict;
use warnings;
use MIME::Base32;

use Pod::Usage;
use Getopt::Long;

my ($opts, $data);

Getopt::Long::Configure("no_ignore_case");

GetOptions(
	'd|decrypt' => \$opts->{'decrypt'},
	'k|key=s' => \$opts->{'key'},
	'h|help' => sub {pod2usage({'-exitval' => 0, '-verbose' => 2})}
) or pod2usage({'-exitval' => 1, '-verbose' => 0});

pod2usage({'-exitval' => 1, '-verbose' => 0}) unless $opts->{'key'} && $ARGV[0];

$opts->{'key'} .= "\0";

if ($opts->{'decrypt'}) {
	$data = MIME::Base32::decode_rfc3548(uc(($ARGV[0] =~ /^([a-z2-7]+)/i)[0]));
	exit unless $data
} else {
	$data = $ARGV[0] . "\0"
}

$opts->{'key'} .= substr($opts->{'key'}, 0, length($data) - length($opts->{'key'}))
	while length($opts->{'key'}) < length($data);
$data .= substr($data, 0, length($opts->{'key'}) - length($data))
	while length($data) < length($opts->{'key'});

if ($opts->{'decrypt'}) {
	printf "%s\n", (($opts->{'key'} ^ $data) =~ /^([\x20-\x7e]+?)\0/i)[0]||"no match."
} else {
	printf "%s\@yourdomain.tld\n", lc MIME::Base32::encode_rfc3548($opts->{'key'} ^ $data, '')
}

__END__

=head1 NAME

mailaddrcrypt-cli

=head1 VERSION

$Revision$

=head1 SYNOPSIS

mailaddrcrypt-cli [OPTIONS] [DATA]

=head1 OPTIONS

=over 8

=item B<-d>,B<--decrypt>

Decrypt I<DATA> instead of encrypting it.

=item B<-k>,B<--key> I<KEY>

Mandatory. Your I<KEY> (e.g. your email address or whatever).

=back

=head1 DESCRIPTION

This script expects some I<DATA> to either encrypt or decrypt using the I<KEY>.
In case of encryption, I<KEY> and I<DATA> get XORed and base32 encoded. In case of decryption the process is reversed.

=head1 DEPENDENCIES

=over 8

=item B<Pod::Usage>

=item B<Getopt::Long>

=item B<MIME::Base32>

=back

=head1 AUTHOR

Philippe Kueck <projects at unixadm dot org>

=cut
